/*
 * Copyright (C) 2012 Red Hat, Inc.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors: Radek Novacek <rnovacek@redhat.com>
 */

#include "endpoint.h"

#include "endpoint_private.h"

Endpoint *endpoint_new_ipv4(Port *port, guint32 address, guint32 prefix, guint32 gateway)
{
    Endpoint *e = endpoint_new(port);
    e->type = IPv4;
    e->ipv4address = ip4ToString(address);
    e->ipv4netmask = prefixToMask4(prefix);
    e->ipv4gateway = ip4ToString(gateway);
    return e;
}

Endpoint *endpoint_new_ipv6(Port *port, GByteArray *address, guint32 prefix, GByteArray *gateway)
{
    Endpoint *e = endpoint_new(port);
    e->type = IPv6;
    e->ipv6address = ip6ToString((const struct in6_addr *) address->data);
    e->ipv6prefix = (uint8_t) prefix;
    if (gateway) {
        e->ipv6gateway = ip6ToString((const struct in6_addr *) gateway->data);
    }
    return e;
}

void endpoint_add_ipv6(Endpoint *e, GByteArray *address, guint32 prefix, GByteArray *gateway)
{
    e->type = IPv4_IPv6;
    e->ipv6address = ip6ToString((const struct in6_addr *) address->data);
    e->ipv6prefix = (uint8_t) prefix;
    if (gateway) {
        e->ipv6gateway = ip6ToString((const struct in6_addr *) gateway->data);
    }
}
