/*
 * Copyright (C) 2012 Red Hat, Inc.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors: Radek Novacek <rnovacek@redhat.com>
 */

#ifndef PORT_H
#define PORT_H

#include "globals.h"

typedef enum PortType {
    TYPE_UNKNOWN = 0,
    TYPE_ETHERNET,
    TYPE_WIFI
} PortType;

typedef enum PortState {
    STATE_UNKNOWN = 0, STATE_NA, STATE_SERVICING, STATE_STARTING,
    STATE_STOPPING, STATE_STOPPED, STATE_ABORTED, STATE_OFFLINE
} PortState;

Port *port_new(void);

void *port_get_priv(const Port *port);
const char *port_get_uuid(const Port *port);
const char *port_get_id(const Port *port);
PortType port_get_type(const Port *port);
PortState port_get_state(const Port *port);

/**
 * Set state of network port
 *
* \param port network port to which the state will be set
 * \param state state to be set
 * \retval 0 success
 * \retval 1 wrong/unsupported state
 * \retval 2 unable to set the state
 */
int port_set_state(Port *port, PortState state, GError **err);
const char *port_get_mac(const Port *port);
const Endpoints *port_get_endpoints(const Port *port);

bool port_compare(const Port *p1, const Port *p2);

void port_free(Port *p);

LIST_DECL(Port, port)

Port *ports_find_by_uuid(Ports *ports, const char *uuid);
Port *ports_find_by_id(Ports *ports, const char *id);

struct PortStat {
    const Port const *port;
    unsigned long rx_bytes;
    unsigned long rx_packets;
    unsigned long rx_errs;
    unsigned long rx_drop;
    unsigned long rx_fifo;
    unsigned long rx_frame;
    unsigned long rx_compressed;
    unsigned long rx_multicast;
    unsigned long tx_bytes;
    unsigned long tx_packets;
    unsigned long tx_errs;
    unsigned long tx_drop;
    unsigned long tx_fifo;
    unsigned long tx_colls;
    unsigned long tx_carrier;
    unsigned long tx_compressed;
};

PortStat *port_stat_new(void);
void port_stat_free(PortStat *);

LIST_DECL(PortStat, port_stat)

#endif
